@@ -267,7 +267,7 @@ import com.jgoodies.binding.value.ValueModel;
  * </ol>
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.26 $
+ * @version $Revision: 1.28 $
  *
  * @see     com.jgoodies.binding.beans.PropertyAdapter
  * @see     ValueModel
@@ -966,14 +966,14 @@ public class BeanAdapter<B> extends Model {
      * Removes the PropertyChangeHandler from the observed bean, if the bean
      * is not {@code null} and if bean property changes are observed.
      * Also removes all listeners from the bean that have been registered
-     * with <code>#addBeanPropertyChangeListener</code> before.<p>
+     * with {@code #addBeanPropertyChangeListener} before.<p>
      *
      * BeanAdapters that observe changes have a PropertyChangeListener
      * registered with the target bean. Hence, a bean has a reference
      * to all BeanAdapters that observe it. To avoid memory leaks
      * it is recommended to remove this listener if the bean lives much longer
      * than the BeanAdapter, enabling the garbage collector to remove the adapter.
-     * To do so, you can call <code>setBean(null)</code> or set the
+     * To do so, you can call {@code setBean(null)} or set the
      * bean channel's value to null.
      * As an alternative you can use event listener lists in your beans
      * that implement references with <code>WeakReference</code>.<p>
@@ -984,8 +984,11 @@ public class BeanAdapter<B> extends Model {
      * However, typically this is fine and setting the bean to null
      * is the first choice for removing the reference from the bean to the adapter.
      * Another way to clear the reference from the target bean is
-     * to call <code>#release</code>. It has no side-effects, but the adapter
-     * must not be used anymore once #release has been called.
+     * to call <code>#release</code>; it has no side-effects.<p>
+     *
+     * Since version 2.0.4 it is safe to call this method multiple times,
+     * however, the adapter must not be used anymore once #release
+     * has been called.
      *
      * @see #setBean(Object)
      * @see java.lang.ref.WeakReference
@@ -1079,7 +1082,8 @@ public class BeanAdapter<B> extends Model {
 
     /**
      * Removes the formerly added property change handler from the given bean
-     * if we observe changes and the bean is not null.
+     * if we observe changes and the bean is not null and we haven't called
+     * this method before.
      *
      * @param bean  the bean to remove the property change handler from.
      * @throws PropertyUnboundException
@@ -1090,7 +1094,7 @@ public class BeanAdapter<B> extends Model {
      * @see #addChangeHandlerTo(Object)
      */
     private void removeChangeHandlerFrom(B bean) {
-        if (!observeChanges || bean == null) {
+        if (!observeChanges || (bean == null) || (propertyChangeHandler == null)) {
             return;
         }
         BeanUtils.removePropertyChangeListener(bean, getBeanClass(bean), propertyChangeHandler);
@@ -1439,6 +1443,31 @@ public class BeanAdapter<B> extends Model {
         }
 
 
+        @Override
+        protected String paramString() {
+            B bean = getBean();
+            Object value = getValue();
+            PropertyDescriptor propertyDescriptor = getPropertyDescriptor(bean);
+            String beanType  = bean  == null ? null : bean.getClass().getName();
+            String valueType = value == null ? null : value.getClass().getName();
+            return
+                  "bean="
+                + bean
+                + "; bean type="
+                + beanType
+                + "; value="
+                + value
+                + "; value type="
+                + valueType
+                + "; property name="
+                + propertyDescriptor.getName()
+                + "; property type="
+                + propertyDescriptor.getPropertyType().getName()
+                + "; property setter="
+                + propertyDescriptor.getWriteMethod();
+        }
+
+
     }
 
 
