@@ -219,7 +219,7 @@ import com.jgoodies.binding.value.ValueModel;
  * </ol>
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.15 $
+ * @version $Revision: 1.17 $
  *
  * @see     com.jgoodies.binding.beans.BeanAdapter
  * @see     ValueModel
@@ -746,6 +746,33 @@ public final class PropertyAdapter<B> extends AbstractValueModel {
     }
 
 
+    // Overriding Superclass Behavior *****************************************
+
+    @Override
+    protected String paramString() {
+        B bean = getBean();
+        Object value = getValue();
+        PropertyDescriptor propertyDescriptor = getPropertyDescriptor(bean);
+        String beanType  = bean  == null ? null : bean.getClass().getName();
+        String valueType = value == null ? null : value.getClass().getName();
+        return
+              "bean="
+            + bean
+            + "; bean type="
+            + beanType
+            + "; value="
+            + value
+            + "; value type="
+            + valueType
+            + "; property name="
+            + propertyDescriptor.getName()
+            + "; property type="
+            + propertyDescriptor.getPropertyType().getName()
+            + "; property setter="
+            + propertyDescriptor.getWriteMethod();
+    }
+
+
     // Changing the Bean & Adding and Removing the PropertyChangeHandler ******
 
     private void setBean0(B oldBean, B newBean) {
@@ -803,7 +830,8 @@ public final class PropertyAdapter<B> extends AbstractValueModel {
 
     /**
      * Removes the formerly added property change handler from the given bean
-     * if we observe changes and the bean is not null.
+     * if we observe changes and the bean is not null and we haven't called
+     * this method before.
      *
      * @param bean  the bean to remove the property change handler from.
      * @throws PropertyUnboundException
@@ -814,7 +842,7 @@ public final class PropertyAdapter<B> extends AbstractValueModel {
      * @see #addChangeHandlerTo(Object)
      */
     private void removeChangeHandlerFrom(B bean) {
-        if (!observeChanges || bean == null)
+        if (!observeChanges || (bean == null) || (propertyChangeHandler == null))
             return;
 
         BeanUtils.removePropertyChangeListener(bean, getBeanClass(bean), propertyChangeHandler);
