@@ -73,7 +73,7 @@ import java.beans.PropertyChangeListener;
  * the trigger channel value of type <code>Boolean</code>.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.11 $
+ * @version $Revision: 1.12 $
  *
  * @see     ValueModel
  * @see     ValueModel#getValue()
@@ -414,6 +414,18 @@ public final class BufferedValueModel extends AbstractValueModel {
     }
 
 
+    // Overriding Superclass Behavior *****************************************
+
+    @Override
+    protected String paramString() {
+        return
+              "value="
+            + valueString()
+            + "; buffering"
+            + isBuffering();
+    }
+
+
     // Helper Class ***********************************************************
 
     /**
