@@ -70,7 +70,7 @@ import com.jgoodies.binding.value.ValueModel;
  * DelayedWriteValueModel, and this DelayedPropertyChangeHandler.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.13 $
+ * @version $Revision: 1.14 $
  *
  * @see DelayedReadValueModel
  * @see DelayedPropertyChangeHandler
@@ -152,7 +152,7 @@ public final class DelayedWriteValueModel extends AbstractValueModel {
      * @return the subject's current or future value.
      */
     public Object getValue() {
-        return hasPendingChange()
+        return isPending()
             ? pendingValue
             : subject.getValue();
     }
@@ -240,8 +240,8 @@ public final class DelayedWriteValueModel extends AbstractValueModel {
     // Misc *******************************************************************
 
     /**
-     * Stops a running timer - if any. The last pending change
-     * won't be performed by the <code>ValueUpdateListener</code>.
+     * Stops a running timer. Pending changes - if any - are canceled
+     * and won't be performed by the <code>ValueUpdateListener</code>.
      *
      * @since 1.2
      */
@@ -250,7 +250,14 @@ public final class DelayedWriteValueModel extends AbstractValueModel {
     }
 
 
-    private boolean hasPendingChange() {
+    /**
+     * Checks and answers whether this model has one or more pending changes.
+     *
+     * @return {@code true} if there are pending changes, {@code false} if not.
+     *
+     * @since 2.0.4
+     */
+    public boolean isPending() {
         return timer.isRunning();
     }
 
