@@ -50,7 +50,7 @@ import com.jgoodies.binding.value.ValueModel;
  * A test case for class {@link com.jgoodies.binding.beans.BeanAdapter}.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.27 $
+ * @version $Revision: 1.28 $
  */
 public final class BeanAdapterTest extends TestCase {
 
@@ -170,6 +170,13 @@ public final class BeanAdapterTest extends TestCase {
     }
 
 
+    public void testAcceptsMultipleReleases() {
+        BeanAdapter<TestBean> adapter = new BeanAdapter<TestBean>(model1);
+        adapter.release();
+        adapter.release();
+    }
+
+
     // Null As Property Name **************************************************
 
     public void testRejectNullPropertyName() {
