@@ -46,11 +46,22 @@ import com.jgoodies.binding.value.ValueHolder;
  * A test case for class {@link com.jgoodies.binding.PresentationModel}.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.12 $
+ * @version $Revision: 1.13 $
  */
 public final class PresentationModelTest extends TestCase {
 
 
+    // Life Cycle *************************************************************
+
+    public void testAcceptsMultipleReleases() {
+        PresentationModel<TestBean> pm = new PresentationModel<TestBean>(new TestBean());
+        pm.release();
+        pm.release();
+    }
+
+
+
+
     // Null As Property Name **************************************************
 
     public void testRejectNullPropertyName() {
