@@ -49,7 +49,7 @@ import com.jgoodies.binding.value.ValueModel;
  * A test case for class {@link PropertyAdapter}.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.25 $
+ * @version $Revision: 1.26 $
  */
 public final class PropertyAdapterTest extends TestCase {
 
@@ -186,6 +186,14 @@ public final class PropertyAdapterTest extends TestCase {
     }
 
 
+    public void testAcceptsMultipleReleases() {
+        PropertyAdapter<TestBean> adapter =
+            new PropertyAdapter<TestBean>(model1, "readOnlyObjectProperty");
+        adapter.release();
+        adapter.release();
+    }
+
+
     // Testing Property Access ************************************************
 
     /**
