@@ -43,7 +43,7 @@ import com.jgoodies.binding.value.ValueModel;
  * A test case for class {@link PropertyConnector}.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.16 $
+ * @version $Revision: 1.17 $
  */
 public final class PropertyConnectorTest extends TestCase {
 
@@ -162,6 +162,18 @@ public final class PropertyConnectorTest extends TestCase {
     }
 
 
+    public void testAcceptsMultipleReleases() {
+        TestBean bean1 = new TestBean();
+        TestBean bean2 = new TestBean();
+        Object initialValue1 = "initialValue1";
+        Object initialValue2 = "initialValue2";
+        PropertyConnector connector =
+            createDefaultConnector(bean1, initialValue1, bean2, initialValue2);
+        connector.release();
+        connector.release();
+    }
+
+
     // Synchronization ********************************************************
 
     public void testUpdateProperty1() {
