@@ -47,7 +47,7 @@ import com.jgoodies.binding.value.ValueModel;
  * A test case for class {@link TextComponentConnector}.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.4 $
+ * @version $Revision: 1.5 $
  */
 public final class TextComponentConnectorTest extends TestCase {
 
@@ -85,6 +85,18 @@ public final class TextComponentConnectorTest extends TestCase {
     }
 
 
+    public void testAcceptsMultipleReleases() {
+        String subjectText  = "subjectText";
+        String fieldText = "fieldText";
+        ValueModel subject  = new ValueHolder(subjectText);
+        JTextField textField = new JTextField(fieldText);
+        TextComponentConnector connector =
+            new TextComponentConnector(subject, textField);
+        connector.release();
+        connector.release();
+    }
+
+
     public void testBindingsUpdatesTextFieldText() {
         String subjectText  = "subjectText";
         String fieldText = "fieldText";
