@@ -44,7 +44,7 @@ import com.jgoodies.binding.beans.Model;
  * can optimize the data transfer and locking for extensible classes only.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.10 $
+ * @version $Revision: 1.11 $
  */
 public class Album extends Model {
 
@@ -69,10 +69,10 @@ public class Album extends Model {
 
     // Names of the Bound Bean Properties *************************************
 
-    public static final String PROPERTYNAME_ARTIST    = "artist";
-    public static final String PROPERTYNAME_CLASSICAL = "classical";
-    public static final String PROPERTYNAME_COMPOSER  = "composer";
-    public static final String PROPERTYNAME_TITLE     = "title";
+    public static final String PROPERTY_ARTIST    = "artist";
+    public static final String PROPERTY_CLASSICAL = "classical";
+    public static final String PROPERTY_COMPOSER  = "composer";
+    public static final String PROPERTY_TITLE     = "title";
 
 
     // Instance Fields ********************************************************
@@ -157,10 +157,8 @@ public class Album extends Model {
     }
 
 
-
     // Accessors **************************************************************
 
-
     /**
      * Returns this album's title, for example "A Love Supreme",
      * or "Symphony No. 5".
@@ -206,7 +204,6 @@ public class Album extends Model {
     }
 
 
-
     /**
      * Sets this album's title and notifies observers
      * if the title changed.
@@ -216,7 +213,7 @@ public class Album extends Model {
     public void setTitle(String title) {
         Object oldValue = getTitle();
         this.title = title;
-        firePropertyChange(PROPERTYNAME_TITLE, oldValue, title);
+        firePropertyChange(PROPERTY_TITLE, oldValue, title);
     }
 
 
@@ -228,7 +225,7 @@ public class Album extends Model {
     public void setArtist(String artist) {
         String oldValue = getArtist();
         this.artist = artist;
-        firePropertyChange(PROPERTYNAME_ARTIST, oldValue, artist);
+        firePropertyChange(PROPERTY_ARTIST, oldValue, artist);
     }
 
 
@@ -241,7 +238,7 @@ public class Album extends Model {
     public void setClassical(boolean classical) {
         boolean oldValue = isClassical();
         this.classical = classical;
-        firePropertyChange(PROPERTYNAME_CLASSICAL, oldValue, classical);
+        firePropertyChange(PROPERTY_CLASSICAL, oldValue, classical);
         if (!classical) {
             setComposer(null);
         }
@@ -259,7 +256,7 @@ public class Album extends Model {
     public void setComposer(String composer) {
         Object oldValue = getComposer();
         this.composer = composer;
-        firePropertyChange(PROPERTYNAME_COMPOSER, oldValue, composer);
+        firePropertyChange(PROPERTY_COMPOSER, oldValue, composer);
     }
 
 
@@ -286,6 +283,7 @@ public class Album extends Model {
         return builder.toString();
     }
 
+
     /**
      * Returns a string representation of this album
      * that contains the property values.
