@@ -66,7 +66,7 @@ import com.jgoodies.binding.value.ValueHolder;
  * that using the buffered classical property would be easier to understand.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.13 $
+ * @version $Revision: 1.14 $
  *
  * @see com.jgoodies.binding.tutorial.manager.BufferedAlbumPresentationModel
  */
@@ -102,7 +102,7 @@ public class AlbumPresentationModel extends PresentationModel<Album> {
      * classical property of the current Album or a new Album.
      */
     private void initEventHandling() {
-        getModel(Album.PROPERTYNAME_CLASSICAL).addValueChangeListener(
+        getModel(Album.PROPERTY_CLASSICAL).addValueChangeListener(
                 new ClassicalChangeHandler());
     }
 
@@ -121,7 +121,7 @@ public class AlbumPresentationModel extends PresentationModel<Album> {
      *     and classical.
      */
     public boolean isComposerEnabled() {
-        return Boolean.TRUE.equals(getModel(Album.PROPERTYNAME_CLASSICAL).getValue());
+        return Boolean.TRUE.equals(getModel(Album.PROPERTY_CLASSICAL).getValue());
     }
 
 
