@@ -31,7 +31,6 @@
 package com.jgoodies.binding.tutorial;
 
 import java.awt.Component;
-import java.awt.Dimension;
 import java.awt.event.ActionEvent;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
@@ -50,7 +49,7 @@ import com.jgoodies.binding.adapter.AbstractTableAdapter;
  * reused in multiple examples of the JGoodies Binding tutorial.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.22 $
+ * @version $Revision: 1.23 $
  */
 public final class TutorialUtils {
 
@@ -108,20 +107,6 @@ public final class TutorialUtils {
     }
 
 
-    /**
-     * Locates the given component on the screen's center.
-     *
-     * @param component   the component to be centered
-     */
-    public static void locateOnOpticalScreenCenter(Component component) {
-        Dimension paneSize = component.getSize();
-        Dimension screenSize = component.getToolkit().getScreenSize();
-        component.setLocation(
-            (screenSize.width  - paneSize.width)  / 2,
-            (int) ((screenSize.height - paneSize.height) *0.45));
-    }
-
-
     // Renderer ***************************************************************
 
     /**
@@ -150,7 +135,8 @@ public final class TutorialUtils {
      */
     private static final class AlbumTableModel extends AbstractTableAdapter<Album> {
 
-        private static final String[] COLUMNS = {"Artist", "Title", "Classical", "Composer"};
+        private static final String[] COLUMNS =
+            {"Artist", "Title", "Classical", "Composer"};
 
         private AlbumTableModel(ListModel listModel) {
             super(listModel, COLUMNS);
