@@ -38,7 +38,7 @@ import javax.swing.text.JTextComponent;
 import com.jgoodies.binding.PresentationModel;
 import com.jgoodies.binding.adapter.BasicComponentFactory;
 import com.jgoodies.binding.beans.Model;
-import com.jgoodies.binding.tutorial.TutorialUtils;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.factories.ButtonBarFactory;
 import com.jgoodies.forms.layout.CellConstraints;
@@ -57,11 +57,11 @@ import com.jgoodies.forms.layout.FormLayout;
  * The same techniques work with any ValueModel.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.11 $
+ * @version $Revision: 1.13 $
  *
  * @see com.jgoodies.binding.PresentationModel
  */
-public final class CommitStylesExample {
+public final class CommitStylesExample extends TutorialApplication {
 
     /**
      * Holds a TextBean and vends ValueModels that adapt TextBean properties.
@@ -82,20 +82,15 @@ public final class CommitStylesExample {
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: Commit Styles");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        CommitStylesExample example = new CommitStylesExample();
-        JComponent panel = example.buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        TutorialApplication.launch(CommitStylesExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Binding Tutorial :: Commit Styles");
+        frame.add(buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
@@ -145,8 +140,8 @@ public final class CommitStylesExample {
         initComponents();
 
         FormLayout layout = new FormLayout(
-                "right:max(50dlu;pref), 3dlu, 50dlu, 9dlu, 50dlu",
-                "p, 6dlu, p, 3dlu, p, 3dlu, p, 17dlu, p");
+                "[50dlu,pref], $lcgap, 50dlu, 9dlu, 50dlu",
+                "p, 6dlu, p, $lgap, p, $lgap, p, 17dlu, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
@@ -154,13 +149,13 @@ public final class CommitStylesExample {
 
         builder.addTitle("Commit Style",    cc.xy (1, 1));
         builder.addTitle("Value",           cc.xy (5, 1));
-        builder.addLabel("Key Typed",       cc.xy (1, 3));
+        builder.addLabel("Key Typed:",      cc.xy (1, 3));
         builder.add(onKeyTypedField,        cc.xy (3, 3));
         builder.add(onKeyTypedLabel,        cc.xy (5, 3));
-        builder.addLabel("Focus Lost",      cc.xy (1, 5));
+        builder.addLabel("Focus Lost:",     cc.xy (1, 5));
         builder.add(onFocusLostField,       cc.xy (3, 5));
         builder.add(onFocusLostLabel,       cc.xy (5, 5));
-        builder.addLabel("Apply Pressed",   cc.xy (1, 7));
+        builder.addLabel("Apply Pressed:",  cc.xy (1, 7));
         builder.add(onApplyField,           cc.xy (3, 7));
         builder.add(onApplyLabel,           cc.xy (5, 7));
         builder.add(buildButtonBar(),       cc.xyw(1, 9, 5));
