@@ -33,13 +33,16 @@ package com.jgoodies.binding.tutorial.basics;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
-import javax.swing.*;
+import javax.swing.JCheckBox;
+import javax.swing.JComponent;
+import javax.swing.JFrame;
+import javax.swing.JTextField;
 
 import com.jgoodies.binding.PresentationModel;
 import com.jgoodies.binding.adapter.BasicComponentFactory;
 import com.jgoodies.binding.beans.Model;
 import com.jgoodies.binding.beans.PropertyConnector;
-import com.jgoodies.binding.tutorial.TutorialUtils;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 import com.jgoodies.binding.value.ComponentValueModel;
 import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.layout.CellConstraints;
@@ -56,14 +59,14 @@ import com.jgoodies.forms.layout.FormLayout;
  * in the ExamplePresentationModel.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.9 $
+ * @version $Revision: 1.11 $
  *
  * @see com.jgoodies.binding.adapter.BasicComponentFactory
  * @see com.jgoodies.binding.adapter.Bindings
  *
  * @since 1.1
  */
-public final class ComponentValueModelExample {
+public final class ComponentValueModelExample extends TutorialApplication {
 
     // Holds an ExampleBean and vends ValueModels that adapt its properties.
     private final ExamplePresentationModel presentationModel;
@@ -79,20 +82,15 @@ public final class ComponentValueModelExample {
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: ComponentValueModel");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        ComponentValueModelExample example = new ComponentValueModelExample();
-        JComponent panel = example.buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        TutorialApplication.launch(ComponentValueModelExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Binding Tutorial :: ComponentValueModel");
+        frame.add(buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
@@ -116,20 +114,20 @@ public final class ComponentValueModelExample {
      */
     private void initComponents() {
         text1Field = BasicComponentFactory.createTextField(
-                presentationModel.getComponentModel(ExampleBean.PROPERTYNAME_TEXT1));
+                presentationModel.getComponentModel(ExampleBean.PROPERTY_TEXT1));
         text2Field = BasicComponentFactory.createTextField(
-                presentationModel.getComponentModel(ExampleBean.PROPERTYNAME_TEXT2));
+                presentationModel.getComponentModel(ExampleBean.PROPERTY_TEXT2));
         text3Field = BasicComponentFactory.createTextField(
-                presentationModel.getComponentModel(ExampleBean.PROPERTYNAME_TEXT3));
+                presentationModel.getComponentModel(ExampleBean.PROPERTY_TEXT3));
 
         enabledBox = BasicComponentFactory.createCheckBox(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_ENABLED),
+                presentationModel.getModel(ExampleBean.PROPERTY_ENABLED),
                 "enabled");
         editableBox = BasicComponentFactory.createCheckBox(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_EDITABLE),
+                presentationModel.getModel(ExampleBean.PROPERTY_EDITABLE),
                 "editable");
         visibleBox = BasicComponentFactory.createCheckBox(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_VISIBLE),
+                presentationModel.getModel(ExampleBean.PROPERTY_VISIBLE),
                 "visible");
     }
 
@@ -145,19 +143,19 @@ public final class ComponentValueModelExample {
         initComponents();
 
         FormLayout layout = new FormLayout(
-                "right:pref, 3dlu, 50dlu, 3dlu, pref",
-                "p, 3dlu, p, 3dlu, p");
+                "pref, $lcgap, 50dlu, $rgap, pref",
+                "p, $lgap, p, $lgap, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
-        builder.addLabel("Text1",      cc.xy(1, 1));
+        builder.addLabel("Text1:",     cc.xy(1, 1));
         builder.add(text1Field,        cc.xy(3, 1));
         builder.add(enabledBox,        cc.xy(5, 1));
-        builder.addLabel("Text2",      cc.xy(1, 3));
+        builder.addLabel("Text2:",     cc.xy(1, 3));
         builder.add(text2Field,        cc.xy(3, 3));
         builder.add(editableBox,       cc.xy(5, 3));
-        builder.addLabel("Text3",      cc.xy(1, 5));
+        builder.addLabel("Text3:",     cc.xy(1, 5));
         builder.add(text3Field,        cc.xy(3, 5));
         builder.add(visibleBox,        cc.xy(5, 5));
         return builder.getPanel();
@@ -168,17 +166,17 @@ public final class ComponentValueModelExample {
 
     public static final class ExampleBean extends Model {
 
-        // Names of the Bound Bean Properties *************************************
+        // Names of the Bound Bean Properties *********************************
 
-        public static final String PROPERTYNAME_ENABLED  = "enabled";
-        public static final String PROPERTYNAME_EDITABLE = "editable";
-        public static final String PROPERTYNAME_VISIBLE  = "visible";
-        public static final String PROPERTYNAME_TEXT1    = "text1";
-        public static final String PROPERTYNAME_TEXT2    = "text2";
-        public static final String PROPERTYNAME_TEXT3    = "text3";
+        public static final String PROPERTY_ENABLED  = "enabled";
+        public static final String PROPERTY_EDITABLE = "editable";
+        public static final String PROPERTY_VISIBLE  = "visible";
+        public static final String PROPERTY_TEXT1    = "text1";
+        public static final String PROPERTY_TEXT2    = "text2";
+        public static final String PROPERTY_TEXT3    = "text3";
 
 
-        // Fields *****************************************************************
+        // Fields *************************************************************
 
         private boolean enabled;
         private boolean editable;
@@ -188,7 +186,7 @@ public final class ComponentValueModelExample {
         private String text3;
 
 
-        // Instance Creation ******************************************************
+        // Instance Creation **************************************************
 
         public ExampleBean() {
             enabled = true;
@@ -200,7 +198,7 @@ public final class ComponentValueModelExample {
         }
 
 
-        // Accessors **************************************************************
+        // Accessors **********************************************************
 
         public boolean isEnabled() {
             return enabled;
@@ -209,7 +207,7 @@ public final class ComponentValueModelExample {
         public void setEnabled(boolean newEnabled) {
             boolean oldEnabled = isEnabled();
             enabled = newEnabled;
-            firePropertyChange(PROPERTYNAME_ENABLED, oldEnabled, newEnabled);
+            firePropertyChange(PROPERTY_ENABLED, oldEnabled, newEnabled);
         }
 
 
@@ -220,7 +218,7 @@ public final class ComponentValueModelExample {
         public void setEditable(boolean newEditable) {
             boolean oldEditable = isEditable();
             editable = newEditable;
-            firePropertyChange(PROPERTYNAME_EDITABLE, oldEditable, newEditable);
+            firePropertyChange(PROPERTY_EDITABLE, oldEditable, newEditable);
         }
 
 
@@ -231,7 +229,7 @@ public final class ComponentValueModelExample {
         public void setVisible(boolean newVisible) {
             boolean oldVisible = isVisible();
             visible = newVisible;
-            firePropertyChange(PROPERTYNAME_VISIBLE, oldVisible, newVisible);
+            firePropertyChange(PROPERTY_VISIBLE, oldVisible, newVisible);
         }
 
 
@@ -242,7 +240,7 @@ public final class ComponentValueModelExample {
         public void setText1(String newText) {
             String oldText = getText1();
             text1 = newText;
-            firePropertyChange(PROPERTYNAME_TEXT1, oldText, newText);
+            firePropertyChange(PROPERTY_TEXT1, oldText, newText);
         }
 
 
@@ -253,7 +251,7 @@ public final class ComponentValueModelExample {
         public void setText2(String newText) {
             String oldText = getText2();
             text2 = newText;
-            firePropertyChange(PROPERTYNAME_TEXT2, oldText, newText);
+            firePropertyChange(PROPERTY_TEXT2, oldText, newText);
         }
 
 
@@ -264,7 +262,7 @@ public final class ComponentValueModelExample {
         public void setText3(String newText) {
             String oldText = getText3();
             text3 = newText;
-            firePropertyChange(PROPERTYNAME_TEXT3, oldText, newText);
+            firePropertyChange(PROPERTY_TEXT3, oldText, newText);
         }
 
 
@@ -315,7 +313,7 @@ public final class ComponentValueModelExample {
         private void initEventHandling() {
             // Observe changes in the domain's enabled property
             // to update the enablement of the text1 views.
-            getModel(ExampleBean.PROPERTYNAME_ENABLED).addValueChangeListener(new PropertyChangeListener() {
+            getModel(ExampleBean.PROPERTY_ENABLED).addValueChangeListener(new PropertyChangeListener() {
                 public void propertyChange(PropertyChangeEvent evt) {
                     updateText1ViewsEnablement();
                 }
@@ -328,21 +326,21 @@ public final class ComponentValueModelExample {
             // to update the editable state of text2 views.
             // Update the editable state of all views bound to text2 now.
             PropertyConnector.connectAndUpdate(
-                    getModel(ExampleBean.PROPERTYNAME_EDITABLE),
-                    getComponentModel(ExampleBean.PROPERTYNAME_TEXT2),
+                    getModel(ExampleBean.PROPERTY_EDITABLE),
+                    getComponentModel(ExampleBean.PROPERTY_TEXT2),
                     ComponentValueModel.PROPERTYNAME_EDITABLE);
 
 
             PropertyConnector.connectAndUpdate(
-                    getModel(ExampleBean.PROPERTYNAME_VISIBLE),
-                    getComponentModel(ExampleBean.PROPERTYNAME_TEXT3),
+                    getModel(ExampleBean.PROPERTY_VISIBLE),
+                    getComponentModel(ExampleBean.PROPERTY_TEXT3),
                     ComponentValueModel.PROPERTYNAME_VISIBLE);
         }
 
 
         private void updateText1ViewsEnablement() {
-            boolean enabled = getModel(ExampleBean.PROPERTYNAME_ENABLED).booleanValue();
-            getComponentModel(ExampleBean.PROPERTYNAME_TEXT1).setEnabled(enabled);
+            boolean enabled = getModel(ExampleBean.PROPERTY_ENABLED).booleanValue();
+            getComponentModel(ExampleBean.PROPERTY_TEXT1).setEnabled(enabled);
         }
 
     }
