@@ -54,6 +54,7 @@ import com.jgoodies.binding.list.ArrayListModel;
 import com.jgoodies.binding.list.ObservableList;
 import com.jgoodies.binding.list.SelectionInList;
 import com.jgoodies.binding.tutorial.Album;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 import com.jgoodies.binding.tutorial.TutorialUtils;
 import com.jgoodies.binding.value.BufferedValueModel;
 import com.jgoodies.binding.value.ConverterFactory;
@@ -63,17 +64,18 @@ import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.layout.CellConstraints;
 import com.jgoodies.forms.layout.ColumnSpec;
 import com.jgoodies.forms.layout.FormLayout;
+import com.jgoodies.forms.layout.LayoutMap;
 
 /**
  * Demonstrates how to bind different value types to Swing components.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.26 $
+ * @version $Revision: 1.28 $
  *
  * @see com.jgoodies.binding.adapter.BasicComponentFactory
  * @see com.jgoodies.binding.adapter.Bindings
  */
-public final class ComponentsExample {
+public final class ComponentsExample extends TutorialApplication {
 
     // Holds an ExampleBean and vends ValueModels that adapt its properties.
     private final ExamplePresentationModel presentationModel;
@@ -115,20 +117,16 @@ public final class ComponentsExample {
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: Components");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        ComponentsExample example = new ComponentsExample();
-        JComponent panel = example.buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        TutorialApplication.launch(ComponentsExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        LayoutMap.getRoot().columnPut("label", "[55dlu,pref]");
+        JFrame frame = createFrame("Binding Tutorial :: Components");
+        frame.add(buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
@@ -153,24 +151,24 @@ public final class ComponentsExample {
     private void initComponents() {
         // Text Components
         textField = BasicComponentFactory.createTextField(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_TEXT));
+                presentationModel.getModel(ExampleBean.PROPERTY_TEXT));
         textArea = BasicComponentFactory.createTextArea(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_TEXT));
+                presentationModel.getModel(ExampleBean.PROPERTY_TEXT));
         passwordField = BasicComponentFactory.createPasswordField(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_TEXT));
+                presentationModel.getModel(ExampleBean.PROPERTY_TEXT));
         textLabel = BasicComponentFactory.createLabel(presentationModel
-                .getModel(ExampleBean.PROPERTYNAME_TEXT));
+                .getModel(ExampleBean.PROPERTY_TEXT));
 
         // Formatted Input
         dateField = BasicComponentFactory.createDateField(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_DATE));
+                presentationModel.getModel(ExampleBean.PROPERTY_DATE));
         integerField = BasicComponentFactory.createIntegerField(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_INT_VALUE));
+                presentationModel.getModel(ExampleBean.PROPERTY_INT_VALUE));
         longField = BasicComponentFactory.createLongField(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_LONG_VALUE));
+                presentationModel.getModel(ExampleBean.PROPERTY_LONG_VALUE));
 
         // Choice
-        ValueModel intChoiceModel = presentationModel.getModel(ExampleBean.PROPERTYNAME_INT_CHOICE);
+        ValueModel intChoiceModel = presentationModel.getModel(ExampleBean.PROPERTY_INT_CHOICE);
         leftIntRadio = BasicComponentFactory.createRadioButton(
                 intChoiceModel, ExampleBean.LEFT_INTEGER, "Left");
         centerIntRadio = BasicComponentFactory.createRadioButton(
@@ -180,7 +178,7 @@ public final class ComponentsExample {
         alignmentIntCombo = BasicComponentFactory.createComboBox(
                 new SelectionInList<Integer>(ExampleBean.INTEGER_CHOICES, intChoiceModel));
 
-        ValueModel objectChoiceModel = presentationModel.getModel(ExampleBean.PROPERTYNAME_OBJECT_CHOICE);
+        ValueModel objectChoiceModel = presentationModel.getModel(ExampleBean.PROPERTY_OBJECT_CHOICE);
         leftObjectRadio = BasicComponentFactory.createRadioButton(
                 objectChoiceModel, ExampleBean.LEFT, "Left");
         centerObjectRadio = BasicComponentFactory.createRadioButton(
@@ -208,13 +206,13 @@ public final class ComponentsExample {
 
         // Misc
         checkBox = BasicComponentFactory.createCheckBox(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_BOOLEAN_VALUE),
+                presentationModel.getModel(ExampleBean.PROPERTY_BOOLEAN_VALUE),
                 "available");
         colorPreview = new JPanel();
         colorPreview.setBorder(new LineBorder(Color.GRAY));
         updatePreviewPanel();
 
-        ValueModel floatModel = presentationModel.getModel(ExampleBean.PROPERTYNAME_FLOAT_VALUE);
+        ValueModel floatModel = presentationModel.getModel(ExampleBean.PROPERTY_FLOAT_VALUE);
         slider = new JSlider();
         slider.setModel(new BoundedRangeAdapter(
                 ConverterFactory.createFloatToIntegerConverter(floatModel, 100),
@@ -225,7 +223,7 @@ public final class ComponentsExample {
                         NumberFormat.getPercentInstance()));
         spinner = new JSpinner();
         spinner.setModel(SpinnerAdapterFactory.createNumberAdapter(
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_INT_LIMITED),
+                presentationModel.getModel(ExampleBean.PROPERTY_INT_LIMITED),
                 0,   // defaultValue
                 0,   // minValue
                 100, // maxValue
@@ -233,7 +231,7 @@ public final class ComponentsExample {
     }
 
     private void initEventHandling() {
-        presentationModel.getModel(ExampleBean.PROPERTYNAME_COLOR).addValueChangeListener(
+        presentationModel.getModel(ExampleBean.PROPERTY_COLOR).addValueChangeListener(
                 new ColorUpdateHandler());
     }
 
@@ -266,88 +264,88 @@ public final class ComponentsExample {
 
     private JPanel buildTextPanel() {
         FormLayout layout = new FormLayout(
-                "right:max(50dlu;pref), 3dlu, 50dlu",
-                "p, 3dlu, p, 3dlu, p, 14dlu, 3dlu, p");
+                "$label, $lcgap, 50dlu",
+                "p, $lgap, p, $lgap, p, 14dlu, $lgap, p");
         layout.setRowGroups(new int[][]{{1, 3, 5}});
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
-        builder.addLabel("JTextField",          cc.xy  (1, 1));
+        builder.addLabel("JTextField:",         cc.xy  (1, 1));
         builder.add(textField,                  cc.xy  (3, 1));
-        builder.addLabel("JPasswordField",      cc.xy  (1, 3));
+        builder.addLabel("JPasswordField:",     cc.xy  (1, 3));
         builder.add(passwordField,              cc.xy  (3, 3));
-        builder.addLabel("JTextArea",           cc.xy  (1, 5));
+        builder.addLabel("JTextArea:",          cc.xy  (1, 5));
         builder.add(new JScrollPane(textArea),  cc.xywh(3, 5, 1, 2));
-        builder.addLabel("JLabel",              cc.xy  (1, 8));
+        builder.addLabel("JLabel:",             cc.xy  (1, 8));
         builder.add(textLabel,                  cc.xy  (3, 8));
         return builder.getPanel();
     }
 
     private JPanel buildFormattedPanel() {
         FormLayout layout = new FormLayout(
-                "right:max(50dlu;pref), 3dlu, 50dlu",
-                "p, 3dlu, p, 3dlu, p");
+                "$label, $lcgap, 50dlu",
+                "p, $lgap, p, $lgap, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
-        builder.addLabel("Date",                cc.xy(1, 1));
+        builder.addLabel("Date:",               cc.xy(1, 1));
         builder.add(dateField,                  cc.xy(3, 1));
-        builder.addLabel("Integer",             cc.xy(1, 3));
+        builder.addLabel("Integer:",            cc.xy(1, 3));
         builder.add(integerField,               cc.xy(3, 3));
-        builder.addLabel("Long",                cc.xy(1, 5));
+        builder.addLabel("Long:",               cc.xy(1, 5));
         builder.add(longField,                  cc.xy(3, 5));
         return builder.getPanel();
     }
 
     private JPanel buildChoicesPanel() {
         FormLayout layout = new FormLayout(
-                "right:max(50dlu;pref), 3dlu, p, 6dlu, p, 6dlu, p, 0:grow",
-                "p, 3dlu, p, 3dlu, p, 9dlu, p, 3dlu, p, 3dlu, p");
+                "$label, $lcgap, p, 6dlu, p, 6dlu, p, 0:grow",
+                "p, $lgap, p, $lgap, p, 9dlu, p, $lgap, p, $lgap, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
         builder.addSeparator("Integer Choice",  cc.xyw(1,  1, 8));
-        builder.addLabel("JRadioButton",        cc.xy (1,  3));
+        builder.addLabel("JRadioButton:",       cc.xy (1,  3));
         builder.add(leftIntRadio,               cc.xy (3,  3));
         builder.add(centerIntRadio,             cc.xy (5,  3));
         builder.add(rightIntRadio,              cc.xy (7,  3));
-        builder.addLabel("JComboBox",           cc.xy (1,  5));
+        builder.addLabel("JComboBox:",          cc.xy (1,  5));
         builder.add(alignmentIntCombo,          cc.xyw(3,  5, 3));
 
         builder.addSeparator("Object Choice",   cc.xyw(1,  7, 8));
-        builder.addLabel("JRadioButton",        cc.xy (1,  9));
+        builder.addLabel("JRadioButton:",       cc.xy (1,  9));
         builder.add(leftObjectRadio,            cc.xy (3,  9));
         builder.add(centerObjectRadio,          cc.xy (5,  9));
         builder.add(rightObjectRadio,           cc.xy (7,  9));
-        builder.addLabel("JComboBox",           cc.xy (1, 11));
+        builder.addLabel("JComboBox:",          cc.xy (1, 11));
         builder.add(alignmentObjectCombo,       cc.xyw(3, 11, 3));
         return builder.getPanel();
     }
 
     private JPanel buildListPanel() {
         FormLayout layout = new FormLayout(
-                "right:max(50dlu;pref), 3dlu, 150dlu",
+                "$label, $lcgap, 150dlu",
                 "fill:60dlu, 6dlu, fill:60dlu, 6dlu, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
-        builder.addLabel("JList",               cc.xy(1, 1, "right, top"));
+        builder.addLabel("JList:",              cc.xy(1, 1, "left, top"));
         builder.add(new JScrollPane(list),      cc.xy(3, 1));
-        builder.addLabel("JTable",              cc.xy(1, 3, "right, top"));
+        builder.addLabel("JTable:",             cc.xy(1, 3, "left, top"));
         builder.add(new JScrollPane(table),     cc.xy(3, 3));
-        builder.addLabel("JComboBox",           cc.xy(1, 5));
+        builder.addLabel("JComboBox:",          cc.xy(1, 5));
         builder.add(comboBox,                   cc.xy(3, 5));
         return builder.getPanel();
     }
 
     private JPanel buildMiscPanel() {
         FormLayout layout = new FormLayout(
-                "right:max(50dlu;pref), 3dlu, 50dlu, 3dlu, 50dlu",
-                "p, 3dlu, p, 3dlu, p, 3dlu, p");
+                "$label, $lcgap, 50dlu, 3dlu, 50dlu",
+                "p, $lgap, p, $lgap, p, $lgap, p");
         layout.setRowGroups(new int[][]{{1, 3, 5}});
 
         PanelBuilder builder = new PanelBuilder(layout);
@@ -355,17 +353,17 @@ public final class ComponentsExample {
 
         Action chooseAction = new ChooseColorAction(
                 builder.getPanel(),
-                presentationModel.getModel(ExampleBean.PROPERTYNAME_COLOR));
+                presentationModel.getModel(ExampleBean.PROPERTY_COLOR));
 
         CellConstraints cc = new CellConstraints();
-        builder.addLabel("JCheckBox",          cc.xy(1, 1));
+        builder.addLabel("JCheckBox:",         cc.xy(1, 1));
         builder.add(checkBox,                  cc.xy(3, 1));
-        builder.addLabel("JSlider",            cc.xy(1, 3));
+        builder.addLabel("JSlider:",           cc.xy(1, 3));
         builder.add(slider,                    cc.xy(3, 3));
         builder.add(floatLabel,                cc.xy(5, 3));
-        builder.addLabel("JSpinner",           cc.xy(1, 5));
+        builder.addLabel("JSpinner:",          cc.xy(1, 5));
         builder.add(spinner,                   cc.xy(3, 5));
-        builder.addLabel("JColorChooser",      cc.xy(1, 7));
+        builder.addLabel("JColorChooser:",     cc.xy(1, 7));
         builder.add(colorPreview,              cc.xy(3, 7, "fill, fill"));
         builder.add(new JButton(chooseAction), cc.xy(5, 7, "left, center"));
         return builder.getPanel();
@@ -379,17 +377,17 @@ public final class ComponentsExample {
 
         // Names of the Bound Bean Properties *************************************
 
-        public static final String PROPERTYNAME_BOOLEAN_VALUE  = "booleanValue";
-        public static final String PROPERTYNAME_COLOR          = "color";
-        public static final String PROPERTYNAME_DATE           = "date";
-        public static final String PROPERTYNAME_FLOAT_VALUE    = "floatValue";
-        public static final String PROPERTYNAME_INT_CHOICE     = "intChoice";
-        public static final String PROPERTYNAME_INT_LIMITED    = "intLimited";
-        public static final String PROPERTYNAME_INT_VALUE      = "intValue";
-        public static final String PROPERTYNAME_LIST_SELECTION = "listSelection";
-        public static final String PROPERTYNAME_LONG_VALUE     = "longValue";
-        public static final String PROPERTYNAME_OBJECT_CHOICE  = "objectChoice";
-        public static final String PROPERTYNAME_TEXT           = "text";
+        public static final String PROPERTY_BOOLEAN_VALUE  = "booleanValue";
+        public static final String PROPERTY_COLOR          = "color";
+        public static final String PROPERTY_DATE           = "date";
+        public static final String PROPERTY_FLOAT_VALUE    = "floatValue";
+        public static final String PROPERTY_INT_CHOICE     = "intChoice";
+        public static final String PROPERTY_INT_LIMITED    = "intLimited";
+        public static final String PROPERTY_INT_VALUE      = "intValue";
+        public static final String PROPERTY_LIST_SELECTION = "listSelection";
+        public static final String PROPERTY_LONG_VALUE     = "longValue";
+        public static final String PROPERTY_OBJECT_CHOICE  = "objectChoice";
+        public static final String PROPERTY_TEXT           = "text";
 
 
         // Constants **************************************************************
@@ -456,7 +454,7 @@ public final class ComponentsExample {
         public void setBooleanValue(boolean newBooleanValue) {
             boolean oldBooleanValue = getBooleanValue();
             booleanValue = newBooleanValue;
-            firePropertyChange(PROPERTYNAME_BOOLEAN_VALUE, oldBooleanValue,
+            firePropertyChange(PROPERTY_BOOLEAN_VALUE, oldBooleanValue,
                     newBooleanValue);
         }
 
@@ -469,7 +467,7 @@ public final class ComponentsExample {
         public void setColor(Color newColor) {
             Color oldColor = getColor();
             color = newColor;
-            firePropertyChange(PROPERTYNAME_COLOR, oldColor, newColor);
+            firePropertyChange(PROPERTY_COLOR, oldColor, newColor);
         }
 
 
@@ -480,7 +478,7 @@ public final class ComponentsExample {
         public void setDate(Date newDate) {
             Date oldDate = getDate();
             date = newDate == null ? NO_DATE : newDate.getTime();
-            firePropertyChange(PROPERTYNAME_DATE, oldDate, newDate);
+            firePropertyChange(PROPERTY_DATE, oldDate, newDate);
         }
 
 
@@ -491,7 +489,7 @@ public final class ComponentsExample {
         public void setFloatValue(float newFloatValue) {
             float oldFloatValue = getFloatValue();
             floatValue = newFloatValue;
-            firePropertyChange(PROPERTYNAME_FLOAT_VALUE, oldFloatValue, newFloatValue);
+            firePropertyChange(PROPERTY_FLOAT_VALUE, oldFloatValue, newFloatValue);
         }
 
 
@@ -502,7 +500,7 @@ public final class ComponentsExample {
         public void setIntChoice(int newIntChoice) {
             int oldIntChoice = getIntChoice();
             intChoice = newIntChoice;
-            firePropertyChange(PROPERTYNAME_INT_CHOICE, oldIntChoice,
+            firePropertyChange(PROPERTY_INT_CHOICE, oldIntChoice,
                     newIntChoice);
         }
 
@@ -514,7 +512,7 @@ public final class ComponentsExample {
         public void setIntLimited(int newIntLimited) {
             int oldIntLimited = getIntLimited();
             intLimited = newIntLimited;
-            firePropertyChange(PROPERTYNAME_INT_LIMITED, oldIntLimited, newIntLimited);
+            firePropertyChange(PROPERTY_INT_LIMITED, oldIntLimited, newIntLimited);
         }
 
 
@@ -525,7 +523,7 @@ public final class ComponentsExample {
         public void setIntValue(int newIntValue) {
             int oldIntValue = getIntValue();
             intValue = newIntValue;
-            firePropertyChange(PROPERTYNAME_INT_VALUE, oldIntValue, newIntValue);
+            firePropertyChange(PROPERTY_INT_VALUE, oldIntValue, newIntValue);
         }
 
 
@@ -536,7 +534,7 @@ public final class ComponentsExample {
         public void setLongValue(long newLongValue) {
             long oldLongValue = getLongValue();
             longValue = newLongValue;
-            firePropertyChange(PROPERTYNAME_LONG_VALUE, oldLongValue,
+            firePropertyChange(PROPERTY_LONG_VALUE, oldLongValue,
                     newLongValue);
         }
 
@@ -548,7 +546,7 @@ public final class ComponentsExample {
         public void setObjectChoice(Object newObjectChoice) {
             Object oldObjectChoice = getObjectChoice();
             objectChoice = newObjectChoice;
-            firePropertyChange(PROPERTYNAME_OBJECT_CHOICE, oldObjectChoice,
+            firePropertyChange(PROPERTY_OBJECT_CHOICE, oldObjectChoice,
                     newObjectChoice);
         }
 
@@ -560,7 +558,7 @@ public final class ComponentsExample {
         public void setText(String newText) {
             String oldText = getText();
             text = newText;
-            firePropertyChange(PROPERTYNAME_TEXT, oldText, newText);
+            firePropertyChange(PROPERTY_TEXT, oldText, newText);
         }
 
 
@@ -576,7 +574,7 @@ public final class ComponentsExample {
         public void setListSelection(Album newListSelection) {
             Object oldListSelection = getListSelection();
             listSelection = newListSelection;
-            firePropertyChange(PROPERTYNAME_LIST_SELECTION, oldListSelection, newListSelection);
+            firePropertyChange(PROPERTY_LIST_SELECTION, oldListSelection, newListSelection);
         }
 
     }
@@ -600,7 +598,7 @@ public final class ComponentsExample {
             super(exampleBean);
             selectionInList = new SelectionInList<Album>(
                     exampleBean.getListModel(),
-                    getModel(ExampleBean.PROPERTYNAME_LIST_SELECTION));
+                    getModel(ExampleBean.PROPERTY_LIST_SELECTION));
         }
 
 
