@@ -39,6 +39,7 @@ import com.jgoodies.binding.adapter.BasicComponentFactory;
 import com.jgoodies.binding.beans.PropertyConnector;
 import com.jgoodies.binding.tutorial.Album;
 import com.jgoodies.binding.tutorial.AlbumPresentationModel;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 import com.jgoodies.binding.tutorial.TutorialUtils;
 import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.factories.ButtonBarFactory;
@@ -50,12 +51,12 @@ import com.jgoodies.forms.layout.FormLayout;
  * using adapting ValueModels created by a PresentationModel.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.14 $
+ * @version $Revision: 1.16 $
  *
  * @see com.jgoodies.binding.PresentationModel
  */
 
-public final class EditorBoundExample {
+public final class EditorBoundExample extends TutorialApplication {
 
     /**
      * Holds the edited Album and vends ValueModels that adapt Album properties.
@@ -72,20 +73,15 @@ public final class EditorBoundExample {
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: Editor (Bound)");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        EditorBoundExample example = new EditorBoundExample();
-        JComponent panel = example.buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        TutorialApplication.launch(EditorBoundExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Binding Tutorial :: Editor (Bound)");
+        frame.add(buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
@@ -138,14 +134,14 @@ public final class EditorBoundExample {
      */
     private void initComponents() {
         titleField = BasicComponentFactory.createTextField(
-                presentationModel.getModel(Album.PROPERTYNAME_TITLE));
+                presentationModel.getModel(Album.PROPERTY_TITLE));
         artistField = BasicComponentFactory.createTextField(
-                presentationModel.getModel(Album.PROPERTYNAME_ARTIST));
+                presentationModel.getModel(Album.PROPERTY_ARTIST));
         classicalBox = BasicComponentFactory.createCheckBox(
-                presentationModel.getModel(Album.PROPERTYNAME_CLASSICAL),
+                presentationModel.getModel(Album.PROPERTY_CLASSICAL),
                 "Classical");
         composerField = BasicComponentFactory.createTextField(
-                presentationModel.getModel(Album.PROPERTYNAME_COMPOSER));
+                presentationModel.getModel(Album.PROPERTY_COMPOSER));
         closeButton = new JButton(new CloseAction());
 
         boolean composerEnabled = presentationModel.isComposerEnabled();
@@ -182,19 +178,19 @@ public final class EditorBoundExample {
         initEventHandling();
 
         FormLayout layout = new FormLayout(
-                "right:pref, 3dlu, 150dlu:grow",
-                "p, 3dlu, p, 3dlu, p, 3dlu, p, 9dlu, p");
+                "pref, $lcgap, 150dlu:grow",
+                "p, $lgap, p, $lgap, p, $lgap, p, 9dlu, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
 
-        builder.addLabel("Artist",     cc.xy (1, 1));
+        builder.addLabel("Artist:",    cc.xy (1, 1));
         builder.add(artistField,       cc.xy (3, 1));
-        builder.addLabel("Title",      cc.xy (1, 3));
+        builder.addLabel("Title:",     cc.xy (1, 3));
         builder.add(titleField,        cc.xy (3, 3));
         builder.add(classicalBox,      cc.xy (3, 5));
-        builder.addLabel("Composer",   cc.xy (1, 7));
+        builder.addLabel("Composer:",  cc.xy (1, 7));
         builder.add(composerField,     cc.xy (3, 7));
         builder.add(buildButtonBar(),  cc.xyw(1, 9, 3));
 
