@@ -40,7 +40,7 @@ import javax.swing.text.JTextComponent;
 import com.jgoodies.binding.PresentationModel;
 import com.jgoodies.binding.adapter.BasicComponentFactory;
 import com.jgoodies.binding.tutorial.Album;
-import com.jgoodies.binding.tutorial.TutorialUtils;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 import com.jgoodies.binding.value.ValueModel;
 import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.factories.ButtonBarFactory;
@@ -54,13 +54,13 @@ import com.jgoodies.forms.layout.FormLayout;
  * A second set of components displays the domain object properties.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.16 $
+ * @version $Revision: 1.18 $
  *
  * @see com.jgoodies.binding.PresentationModel
  * @see com.jgoodies.binding.value.BufferedValueModel
  * @see com.jgoodies.binding.value.Trigger
  */
-public final class EditorBufferedExample {
+public final class EditorBufferedExample extends TutorialApplication {
 
     /**
      * Holds the edited Album and vends ValueModels that adapt Album properties.
@@ -85,20 +85,15 @@ public final class EditorBufferedExample {
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: Editor (Bound, Buffered)");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        EditorBufferedExample example = new EditorBufferedExample();
-        JComponent panel = example.buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        TutorialApplication.launch(EditorBufferedExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Binding Tutorial :: Editor (Bound, Buffered)");
+        frame.add(buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
@@ -131,27 +126,27 @@ public final class EditorBufferedExample {
      */
     private void initComponents() {
         titleField = BasicComponentFactory.createTextField(
-                presentationModel.getBufferedModel(Album.PROPERTYNAME_TITLE));
+                presentationModel.getBufferedModel(Album.PROPERTY_TITLE));
         artistField = BasicComponentFactory.createTextField(
-                presentationModel.getBufferedModel(Album.PROPERTYNAME_ARTIST));
+                presentationModel.getBufferedModel(Album.PROPERTY_ARTIST));
         classicalBox = BasicComponentFactory.createCheckBox (
-                presentationModel.getBufferedModel(Album.PROPERTYNAME_CLASSICAL),
+                presentationModel.getBufferedModel(Album.PROPERTY_CLASSICAL),
                 "Classical");
         composerField = BasicComponentFactory.createTextField(
-                presentationModel.getBufferedModel(Album.PROPERTYNAME_COMPOSER));
+                presentationModel.getBufferedModel(Album.PROPERTY_COMPOSER));
 
         unbufferedTitleField = BasicComponentFactory.createTextField(
-                presentationModel.getModel(Album.PROPERTYNAME_TITLE));
+                presentationModel.getModel(Album.PROPERTY_TITLE));
         unbufferedTitleField.setEditable(false);
         unbufferedArtistField = BasicComponentFactory.createTextField(
-                presentationModel.getModel(Album.PROPERTYNAME_ARTIST));
+                presentationModel.getModel(Album.PROPERTY_ARTIST));
         unbufferedArtistField.setEditable(false);
         unbufferedClassicalBox = BasicComponentFactory.createCheckBox (
-                presentationModel.getModel(Album.PROPERTYNAME_CLASSICAL),
+                presentationModel.getModel(Album.PROPERTY_CLASSICAL),
                 "Classical");
         unbufferedClassicalBox.setEnabled(false);
         unbufferedComposerField = BasicComponentFactory.createTextField(
-                presentationModel.getModel(Album.PROPERTYNAME_COMPOSER));
+                presentationModel.getModel(Album.PROPERTY_COMPOSER));
         unbufferedComposerField.setEditable(false);
 
         applyButton = new JButton(new ApplyAction());
@@ -175,7 +170,7 @@ public final class EditorBufferedExample {
      */
     private void initEventHandling() {
         ValueModel bufferedClassicalModel =
-            presentationModel.getBufferedModel(Album.PROPERTYNAME_CLASSICAL);
+            presentationModel.getBufferedModel(Album.PROPERTY_CLASSICAL);
         bufferedClassicalModel.addValueChangeListener(
                 new BufferedClassicalChangeHandler());
     }
@@ -193,30 +188,30 @@ public final class EditorBufferedExample {
         initEventHandling();
 
         FormLayout layout = new FormLayout(
-                "right:pref, 3dlu, 150dlu:grow",
-                "p, 3dlu, p, 3dlu, p, 3dlu, p, 3dlu, p, 17dlu, " +
-                "p, 3dlu, p, 3dlu, p, 3dlu, p, 3dlu, p, 17dlu, p");
+                "pref, $lcgap, 150dlu:grow",
+                "p, $lgap, p, $lgap, p, $lgap, p, $lgap, p, 17dlu, " +
+                "p, $lgap, p, $lgap, p, $lgap, p, $lgap, p, 17dlu, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
 
         builder.addSeparator("Buffered",        cc.xyw(1,  1, 3));
-        builder.addLabel("Artist",              cc.xy (1,  3));
+        builder.addLabel("Artist:",             cc.xy (1,  3));
         builder.add(artistField,                cc.xy (3,  3));
-        builder.addLabel("Title",               cc.xy (1,  5));
+        builder.addLabel("Title:",              cc.xy (1,  5));
         builder.add(titleField,                 cc.xy (3,  5));
         builder.add(classicalBox,               cc.xy (3,  7));
-        builder.addLabel("Composer",            cc.xy (1,  9));
+        builder.addLabel("Composer:",           cc.xy (1,  9));
         builder.add(composerField,              cc.xy (3,  9));
 
         builder.addSeparator("Unbuffered",      cc.xyw(1, 11, 3));
-        builder.addLabel("Artist",              cc.xy (1, 13));
+        builder.addLabel("Artist:",             cc.xy (1, 13));
         builder.add(unbufferedArtistField,      cc.xy (3, 13));
-        builder.addLabel("Title",               cc.xy (1, 15));
+        builder.addLabel("Title:",              cc.xy (1, 15));
         builder.add(unbufferedTitleField,       cc.xy (3, 15));
         builder.add(unbufferedClassicalBox,     cc.xy (3, 17));
-        builder.addLabel("Composer",            cc.xy (1, 19));
+        builder.addLabel("Composer:",           cc.xy (1, 19));
         builder.add(unbufferedComposerField,    cc.xy (3, 19));
 
         builder.add(buildButtonBar(),           cc.xyw(1, 21, 3));
@@ -242,10 +237,10 @@ public final class EditorBufferedExample {
      */
     private void updateComposerField() {
         boolean composerEnabled = ((Boolean) presentationModel
-                .getBufferedValue(Album.PROPERTYNAME_CLASSICAL)).booleanValue();
+                .getBufferedValue(Album.PROPERTY_CLASSICAL)).booleanValue();
         composerField.setEnabled(composerEnabled);
         if (!composerEnabled) {
-            presentationModel.setBufferedValue(Album.PROPERTYNAME_COMPOSER, null);
+            presentationModel.setBufferedValue(Album.PROPERTY_COMPOSER, null);
         }
     }
 
