@@ -38,6 +38,7 @@ import javax.swing.event.ChangeListener;
 import javax.swing.text.JTextComponent;
 
 import com.jgoodies.binding.tutorial.Album;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 import com.jgoodies.binding.tutorial.TutorialUtils;
 import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.factories.ButtonBarFactory;
@@ -56,10 +57,10 @@ import com.jgoodies.forms.layout.FormLayout;
  * edited Album via <code>#updateModel</code> when OK is pressed.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.16 $
+ * @version $Revision: 1.18 $
  */
 
-public final class EditorCopyingExample {
+public final class EditorCopyingExample extends TutorialApplication {
 
     /**
      * Refers to the Album that is to be edited by this example editor.
@@ -78,21 +79,16 @@ public final class EditorCopyingExample {
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: Editor (Copying)");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        EditorCopyingExample example = new EditorCopyingExample();
-        JComponent panel = example.buildPanel();
-        example.updateView();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        TutorialApplication.launch(EditorCopyingExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Binding Tutorial :: Editor (Copying)");
+        frame.add(buildPanel());
+        updateView();
+        packAndShowOnScreenCenter(frame);
     }
 
 
@@ -186,19 +182,19 @@ public final class EditorCopyingExample {
         initEventHandling();
 
         FormLayout layout = new FormLayout(
-                "right:pref, 3dlu, 150dlu:grow",
-                "p, 3dlu, p, 3dlu, p, 3dlu, p, 9dlu, p");
+                "pref, $lcgap, 150dlu:grow",
+                "p, $lgap, p, $lgap, p, $lgap, p, 9dlu, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
 
-        builder.addLabel("Artist",    cc.xy (1, 1));
+        builder.addLabel("Artist:",   cc.xy (1, 1));
         builder.add(artistField,      cc.xy (3, 1));
-        builder.addLabel("Title",     cc.xy (1, 3));
+        builder.addLabel("Title:",    cc.xy (1, 3));
         builder.add(titleField,       cc.xy (3, 3));
         builder.add(classicalBox,     cc.xy (3, 5));
-        builder.addLabel("Composer",  cc.xy (1, 7));
+        builder.addLabel("Composer:", cc.xy (1, 7));
         builder.add(composerField,    cc.xy (3, 7));
         builder.add(buildButtonBar(), cc.xyw(1, 9, 3));
 
