@@ -40,6 +40,7 @@ import javax.swing.text.JTextComponent;
 import com.jgoodies.binding.PresentationModel;
 import com.jgoodies.binding.adapter.BasicComponentFactory;
 import com.jgoodies.binding.tutorial.Album;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 import com.jgoodies.binding.tutorial.TutorialUtils;
 import com.jgoodies.binding.value.ConverterFactory;
 import com.jgoodies.binding.value.ValueHolder;
@@ -65,13 +66,13 @@ import com.jgoodies.forms.layout.FormLayout;
  * the details UI components to the details PresentationModel's ValueModels.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.15 $
+ * @version $Revision: 1.17 $
  *
  * @see com.jgoodies.binding.PresentationModel
  * @see com.jgoodies.binding.tutorial.basics.MasterDetailsCopyingExample
  * @see com.jgoodies.binding.tutorial.basics.MasterDetailsSelectionInListExample
  */
-public final class MasterDetailsBoundExample {
+public final class MasterDetailsBoundExample extends TutorialApplication {
 
     /**
      * The Albums displayed in the master list.
@@ -94,19 +95,15 @@ public final class MasterDetailsBoundExample {
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: Master/Details (Bound)");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        JComponent panel = new MasterDetailsBoundExample().buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        TutorialApplication.launch(MasterDetailsBoundExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Binding Tutorial :: Master/Details (Bound)");
+        frame.add(buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
@@ -162,19 +159,19 @@ public final class MasterDetailsBoundExample {
         albumsList.setCellRenderer(TutorialUtils.createAlbumListCellRenderer());
 
         titleField = BasicComponentFactory.createTextField(
-                detailsModel.getModel(Album.PROPERTYNAME_TITLE));
+                detailsModel.getModel(Album.PROPERTY_TITLE));
         titleField.setEditable(false);
         artistField = BasicComponentFactory.createTextField(
-                detailsModel.getModel(Album.PROPERTYNAME_ARTIST));
+                detailsModel.getModel(Album.PROPERTY_ARTIST));
         artistField.setEditable(false);
         classicalField = BasicComponentFactory.createTextField(
                 ConverterFactory.createBooleanToStringConverter(
-                        detailsModel.getModel(Album.PROPERTYNAME_CLASSICAL),
+                        detailsModel.getModel(Album.PROPERTY_CLASSICAL),
                         "Yes",
                         "No"));
         classicalField.setEditable(false);
         composerField = BasicComponentFactory.createTextField(
-                detailsModel.getModel(Album.PROPERTYNAME_COMPOSER));
+                detailsModel.getModel(Album.PROPERTY_COMPOSER));
         composerField.setEditable(false);
         closeButton = new JButton(TutorialUtils.getCloseAction());
     }
@@ -198,8 +195,8 @@ public final class MasterDetailsBoundExample {
         initEventHandling();
 
         FormLayout layout = new FormLayout(
-                "right:pref, 3dlu, 150dlu:grow",
-                "p, 1dlu, p, 9dlu, p, 1dlu, p, 3dlu, p, 3dlu, p, 3dlu, p, 9dlu, p");
+                "pref, $lcgap, 150dlu:grow",
+                "p, 1dlu, p, 9dlu, p, 1dlu, p, $lgap, p, $lgap, p, $lgap, p, 9dlu, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
@@ -210,13 +207,13 @@ public final class MasterDetailsBoundExample {
                         albumsList),    cc.xy (3,  3));
 
         builder.addSeparator("Details", cc.xyw(1,  5, 3));
-        builder.addLabel("Artist",      cc.xy (1,  7));
+        builder.addLabel("Artist:",     cc.xy (1,  7));
         builder.add(artistField,        cc.xy (3,  7));
-        builder.addLabel("Title",       cc.xy (1,  9));
+        builder.addLabel("Title:",      cc.xy (1,  9));
         builder.add(titleField,         cc.xy (3,  9));
-        builder.addLabel("Classical",   cc.xy (1, 11));
+        builder.addLabel("Classical:",  cc.xy (1, 11));
         builder.add(classicalField,     cc.xy (3, 11));
-        builder.addLabel("Composer",    cc.xy (1, 13));
+        builder.addLabel("Composer:",   cc.xy (1, 13));
         builder.add(composerField,      cc.xy (3, 13));
         builder.add(buildButtonBar(),   cc.xyw(1, 15, 3));
 
