@@ -38,6 +38,7 @@ import javax.swing.event.ListSelectionListener;
 import javax.swing.text.JTextComponent;
 
 import com.jgoodies.binding.tutorial.Album;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 import com.jgoodies.binding.tutorial.TutorialUtils;
 import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.factories.ButtonBarFactory;
@@ -57,12 +58,12 @@ import com.jgoodies.forms.layout.FormLayout;
  * as bean channel for the details PresentationModel.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.16 $
+ * @version $Revision: 1.18 $
  *
  * @see com.jgoodies.binding.tutorial.basics.MasterDetailsBoundExample
  * @see com.jgoodies.binding.tutorial.basics.MasterDetailsSelectionInListExample
  */
-public final class MasterDetailsCopyingExample {
+public final class MasterDetailsCopyingExample extends TutorialApplication {
 
     /**
      * The Albums displayed in the overview list.
@@ -85,19 +86,15 @@ public final class MasterDetailsCopyingExample {
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: Master/Details (Copying)");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        JComponent panel = new MasterDetailsCopyingExample().buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        TutorialApplication.launch(MasterDetailsCopyingExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Binding Tutorial :: Master/Details (Copying)");
+        frame.add(buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
@@ -110,6 +107,7 @@ public final class MasterDetailsCopyingExample {
         this(Album.ALBUMS);
     }
 
+
     /**
      * Constructs a list editor for editing the given list of Albums.
      *
@@ -177,8 +175,8 @@ public final class MasterDetailsCopyingExample {
         initEventHandling();
 
         FormLayout layout = new FormLayout(
-                "right:pref, 3dlu, 150dlu:grow",
-                "p, 1dlu, p, 9dlu, p, 1dlu, p, 3dlu, p, 3dlu, p, 3dlu, p, 9dlu, p");
+                "pref, $lcgap, 150dlu:grow",
+                "p, 1dlu, p, 9dlu, p, 1dlu, p, $lgap, p, $lgap, p, $lgap, p, 9dlu, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
@@ -189,13 +187,13 @@ public final class MasterDetailsCopyingExample {
                         albumsList),     cc.xy (3,  3));
 
         builder.addSeparator("Details",  cc.xyw(1,  5, 3));
-        builder.addLabel("Artist",       cc.xy (1,  7));
+        builder.addLabel("Artist:",      cc.xy (1,  7));
         builder.add(artistField,         cc.xy (3,  7));
-        builder.addLabel("Title",        cc.xy (1,  9));
+        builder.addLabel("Title:",       cc.xy (1,  9));
         builder.add(titleField,          cc.xy (3,  9));
-        builder.addLabel("Classical",    cc.xy (1, 11));
+        builder.addLabel("Classical:",   cc.xy (1, 11));
         builder.add(classicalField,      cc.xy (3, 11));
-        builder.addLabel("Composer",     cc.xy (1, 13));
+        builder.addLabel("Composer:",    cc.xy (1, 13));
         builder.add(composerField,       cc.xy (3, 13));
         builder.add(buildButtonBar(),    cc.xyw(1, 15, 3));
 
