@@ -39,6 +39,7 @@ import com.jgoodies.binding.PresentationModel;
 import com.jgoodies.binding.adapter.BasicComponentFactory;
 import com.jgoodies.binding.list.SelectionInList;
 import com.jgoodies.binding.tutorial.Album;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 import com.jgoodies.binding.tutorial.TutorialUtils;
 import com.jgoodies.binding.value.ConverterFactory;
 import com.jgoodies.binding.value.DelayedReadValueModel;
@@ -68,14 +69,14 @@ import com.jgoodies.forms.layout.FormLayout;
  * delay before the selection becomes the presentation model's new bean.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.11 $
+ * @version $Revision: 1.13 $
  *
  * @see #initComponents()
  * @see DelayedReadValueModel
  * @see com.jgoodies.binding.PresentationModel
  * @see com.jgoodies.binding.tutorial.basics.MasterDetailsSelectionInListExample
  */
-public final class MasterDetailsDelayedReadExample {
+public final class MasterDetailsDelayedReadExample extends TutorialApplication {
 
     /**
      * The default in milliseconds to wait before a selection change
@@ -104,19 +105,15 @@ public final class MasterDetailsDelayedReadExample {
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: Master/Details (Delayed)");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        JComponent panel = new MasterDetailsDelayedReadExample().buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        TutorialApplication.launch(MasterDetailsDelayedReadExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Binding Tutorial :: Master/Details (Delayed)");
+        frame.add(buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
@@ -130,6 +127,7 @@ public final class MasterDetailsDelayedReadExample {
         this(Album.ALBUMS);
     }
 
+
     /**
      * Constructs a delayed list editor for editing the given list of Albums
      * using the default delay.
@@ -186,19 +184,19 @@ public final class MasterDetailsDelayedReadExample {
                 TutorialUtils.createAlbumListCellRenderer());
 
         titleField = BasicComponentFactory.createTextField(
-                detailsModel.getModel(Album.PROPERTYNAME_TITLE));
+                detailsModel.getModel(Album.PROPERTY_TITLE));
         titleField.setEditable(false);
         artistField = BasicComponentFactory.createTextField(
-                detailsModel.getModel(Album.PROPERTYNAME_ARTIST));
+                detailsModel.getModel(Album.PROPERTY_ARTIST));
         artistField.setEditable(false);
         classicalField = BasicComponentFactory.createTextField(
                 ConverterFactory.createBooleanToStringConverter(
-                        detailsModel.getModel(Album.PROPERTYNAME_CLASSICAL),
+                        detailsModel.getModel(Album.PROPERTY_CLASSICAL),
                         "Yes",
                         "No"));
         classicalField.setEditable(false);
         composerField = BasicComponentFactory.createTextField(
-                detailsModel.getModel(Album.PROPERTYNAME_COMPOSER));
+                detailsModel.getModel(Album.PROPERTY_COMPOSER));
         composerField.setEditable(false);
         closeButton = new JButton(TutorialUtils.getCloseAction());
     }
@@ -216,8 +214,8 @@ public final class MasterDetailsDelayedReadExample {
         initComponents();
 
         FormLayout layout = new FormLayout(
-                "right:pref, 3dlu, 150dlu:grow",
-        "p, 1dlu, p, 9dlu, p, 1dlu, p, 3dlu, p, 3dlu, p, 3dlu, p, 9dlu, p");
+                "pref, $lcgap, 150dlu:grow",
+        "p, 1dlu, p, 9dlu, p, 1dlu, p, $lgap, p, $lgap, p, $lgap, p, 9dlu, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
@@ -229,13 +227,13 @@ public final class MasterDetailsDelayedReadExample {
 
         builder.addSeparator("Delayed Details",
                                         cc.xyw(1,  5, 3));
-        builder.addLabel("Artist",      cc.xy (1,  7));
+        builder.addLabel("Artist:",     cc.xy (1,  7));
         builder.add(artistField,        cc.xy (3,  7));
-        builder.addLabel("Title",       cc.xy (1,  9));
+        builder.addLabel("Title:",      cc.xy (1,  9));
         builder.add(titleField,         cc.xy (3,  9));
-        builder.addLabel("Classical",   cc.xy (1, 11));
+        builder.addLabel("Classical:",  cc.xy (1, 11));
         builder.add(classicalField,     cc.xy (3, 11));
-        builder.addLabel("Composer",    cc.xy (1, 13));
+        builder.addLabel("Composer:",   cc.xy (1, 13));
         builder.add(composerField,      cc.xy (3, 13));
         builder.add(buildButtonBar(),   cc.xyw(1, 15, 3));
 
