@@ -37,7 +37,6 @@ import javax.swing.*;
 import javax.swing.border.EmptyBorder;
 
 import com.jgoodies.binding.tutorial.Album;
-import com.jgoodies.binding.tutorial.TutorialUtils;
 import com.jgoodies.forms.builder.PanelBuilder;
 import com.jgoodies.forms.factories.Borders;
 import com.jgoodies.forms.factories.ButtonBarFactory;
@@ -50,7 +49,7 @@ import com.jgoodies.forms.layout.FormLayout;
  * These buttons trigger a commit or flush in the dialog's PresentationModel.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.17 $
+ * @version $Revision: 1.19 $
  *
  * @see AlbumEditorView
  * @see AlbumManagerModel
@@ -148,14 +147,14 @@ public final class AlbumEditorDialog extends JDialog {
         setContentPane(buildContentPane());
         pack();
         setResizable(false);
-        TutorialUtils.locateOnOpticalScreenCenter(this);
+        setLocationRelativeTo(null);
     }
 
 
     private JComponent buildContentPane() {
         FormLayout layout = new FormLayout(
                 "fill:pref",
-                "fill:pref, 6dlu, pref");
+                "fill:pref, $ugap, pref");
         PanelBuilder builder = new PanelBuilder(layout);
         builder.getPanel().setBorder(new EmptyBorder(18, 12, 12, 12));
         CellConstraints cc = new CellConstraints();
