@@ -49,7 +49,7 @@ import com.jgoodies.forms.layout.FormLayout;
  * the PresentationModel updates its bean, in this case the Album.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.8 $
+ * @version $Revision: 1.10 $
  *
  * @see AlbumManagerModel
  * @see com.jgoodies.binding.tutorial.AlbumPresentationModel
@@ -89,14 +89,14 @@ public final class AlbumEditorView {
      */
     private void initComponents() {
         titleField = BasicComponentFactory.createTextField(
-                presentationModel.getBufferedModel(Album.PROPERTYNAME_TITLE));
+                presentationModel.getBufferedModel(Album.PROPERTY_TITLE));
         artistField = BasicComponentFactory.createTextField(
-                presentationModel.getBufferedModel(Album.PROPERTYNAME_ARTIST));
+                presentationModel.getBufferedModel(Album.PROPERTY_ARTIST));
         classicalBox = BasicComponentFactory.createCheckBox(
-                presentationModel.getBufferedModel(Album.PROPERTYNAME_CLASSICAL),
+                presentationModel.getBufferedModel(Album.PROPERTY_CLASSICAL),
                 "Classical");
         composerField = BasicComponentFactory.createTextField(
-                presentationModel.getBufferedModel(Album.PROPERTYNAME_COMPOSER));
+                presentationModel.getBufferedModel(Album.PROPERTY_COMPOSER));
     }
 
 
@@ -128,20 +128,20 @@ public final class AlbumEditorView {
         initEventHandling();
 
         FormLayout layout = new FormLayout(
-                "right:pref, 3dlu, 150dlu:grow",
-                "p, 3dlu, p, 3dlu, p, 3dlu, p");
+                "pref, $lcgap, 150dlu:grow",
+                "p, $lgap, p, $lgap, p, $lgap, p");
         layout.setRowGroups(new int[][]{{1, 3, 5, 7}});
 
         PanelBuilder builder = new PanelBuilder(layout);
         CellConstraints cc = new CellConstraints();
 
-        builder.addLabel("Artist",   cc.xy(1, 1));
-        builder.add(artistField,     cc.xy(3, 1));
-        builder.addLabel("Title",    cc.xy(1, 3));
-        builder.add(titleField,      cc.xy(3, 3));
-        builder.add(classicalBox,    cc.xy(3, 5));
-        builder.addLabel("Composer", cc.xy(1, 7));
-        builder.add(composerField,   cc.xy(3, 7));
+        builder.addLabel("Artist:",   cc.xy(1, 1));
+        builder.add(artistField,      cc.xy(3, 1));
+        builder.addLabel("Title:",    cc.xy(1, 3));
+        builder.add(titleField,       cc.xy(3, 3));
+        builder.add(classicalBox,     cc.xy(3, 5));
+        builder.addLabel("Composer:", cc.xy(1, 7));
+        builder.add(composerField,    cc.xy(3, 7));
 
         return builder.getPanel();
     }
