@@ -48,7 +48,7 @@ import com.jgoodies.forms.layout.FormLayout;
  * The models and Actions are provided by an underlying AlbumManagerModel.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.6 $
+ * @version $Revision: 1.7 $
  *
  * @see AlbumManagerModel
  * @see com.jgoodies.binding.PresentationModel
@@ -116,7 +116,7 @@ public final class AlbumManagerView {
 
         FormLayout layout = new FormLayout(
                 "fill:250dlu:grow",
-                "p, 1dlu, fill:200dlu, 6dlu, p");
+                "p, 1dlu, fill:200dlu, $ugap, p");
 
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
