@@ -57,7 +57,7 @@ import com.jgoodies.binding.tutorial.AlbumPresentationModel;
  * Model</a> pattern.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.8 $
+ * @version $Revision: 1.9 $
  *
  * @see AlbumPresentationModel
  */
@@ -97,7 +97,7 @@ public final class BufferedAlbumPresentationModel extends AlbumPresentationModel
      * property is false.
      */
     private void initEventHandling() {
-        getBufferedModel(Album.PROPERTYNAME_CLASSICAL).addValueChangeListener(
+        getBufferedModel(Album.PROPERTY_CLASSICAL).addValueChangeListener(
                 new BufferedClassicalChangeHandler());
     }
 
@@ -127,7 +127,7 @@ public final class BufferedAlbumPresentationModel extends AlbumPresentationModel
      *     and the buffered classical property is true.
      */
     private boolean isBufferedClassical() {
-        return Boolean.TRUE.equals(getBufferedModel(Album.PROPERTYNAME_CLASSICAL).getValue());
+        return Boolean.TRUE.equals(getBufferedModel(Album.PROPERTY_CLASSICAL).getValue());
     }
 
 
@@ -158,7 +158,7 @@ public final class BufferedAlbumPresentationModel extends AlbumPresentationModel
                     null,
                     Boolean.valueOf(isBufferedComposerEnabled()));
             if (!isBufferedClassical()) {
-                getBufferedModel(Album.PROPERTYNAME_COMPOSER).setValue(null);
+                getBufferedModel(Album.PROPERTY_COMPOSER).setValue(null);
             }
         }
     }
